.. image:: https://anaconda.org/conda-forge/gammapy/badges/license.svg
   :target: https://github.com/gammapy/gammapy/blob/master/LICENSE.rst
   :alt: Licence

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
   :target: http://www.astropy.org/
|
.. image:: https://anaconda.org/conda-forge/gammapy/badges/platforms.svg
   :target: https://anaconda.org/conda-forge/gammapy
|
.. image:: http://img.shields.io/pypi/v/gammapy.svg?text=version
   :target: https://pypi.org/project/gammapy/
   :alt: Latest release

.. image:: https://img.shields.io/pypi/dm/gammapy?label=downloads%20%7C%20pip&logo=PyPI
   :alt: PyPI - Downloads

.. image:: https://anaconda.org/conda-forge/gammapy/badges/version.svg
   :target: https://anaconda.org/conda-forge/gammapy

.. image:: https://img.shields.io/conda/dn/conda-forge/gammapy?label=downloads%20%7C%20conda&logo=Conda-Forge
   :target: https://anaconda.org/conda-forge/gammapy

.. image:: https://img.shields.io/badge/launch-binder-579aca.svg?logo=data:image/png;base64, 
   :target: mybinder.org
|
.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.4701488.svg?style=flat
   :target: https://doi.org/10.5281/zenodo.4701488

.. image:: https://archive.softwareheritage.org/badge/origin/https://github.com/gammapy/gammapy/
   :target: https://archive.softwareheritage.org/browse/origin/?origin_url=https://github.com/gammapy/gammapy

.. image:: https://archive.softwareheritage.org/badge/swh:1:snp:11e81660a96c3252c4afa4d48b58d1d2f78ea80a/
   :target: https://archive.softwareheritage.org/swh:1:snp:11e81660a96c3252c4afa4d48b58d1d2f78ea80a;origin=https://github.com/gammapy/gammapy
|
.. image:: https://img.shields.io/badge/A&A-Published-Green.svg
   :target: https://doi.org/10.1051/0004-6361/202346488
|
.. image:: https://img.shields.io/badge/Matomo-3152A0?style=for-the-badge&logo=Matomo&logoColor=white
   :target: https://matomo.org/

Gammapy
=======

A Python Package for Gamma-ray Astronomy.

Gammapy is an open-source Python package for gamma-ray astronomy built on Numpy, Scipy and Astropy. It is used as core
library for the Science Analysis tools of the Cherenkov Telescope Array (CTA), recommended by the H.E.S.S.
collaboration to be used for Science publications, and is already widely used in the analysis of existing gamma-ray
instruments, such as MAGIC, VERITAS and HAWC.

* Webpage: https://gammapy.org
* Documentation: https://docs.gammapy.org/
* Code: https://github.com/gammapy/gammapy

Contributing Code, Documentation, or Feedback
+++++++++++++++++++++++++++++++++++++++++++++
The Gammapy Project is made both by and for its users, so we welcome and encourage contributions of many kinds. Our
goal is to keep this a positive, inclusive, successful, and growing community by abiding with the
`Gammapy Community Code of Conduct <https://gammapy.org/CoC.html>`_.

The Gammapy project uses a mechanism known as a `Developer Certificate of Origin` (DCO). The DCO is a binding statement
that asserts that you are the creator of your contribution, and that you wish to allow Gammapy to use your work to cite
you as contributor. More detailed information on contributing to the project or submitting feedback can be found on the
`Contributing page <https://github.com/gammapy/gammapy/blob/master/CONTRIBUTING.md>`_.

Licence
+++++++
Gammapy is licensed under a 3-clause BSD style license - see the
`LICENSE.rst <https://github.com/gammapy/gammapy/blob/master/LICENSE.rst>`_ file.

The Gammapy documentation is licensed under the `CC BY-NC-SA <https://creativecommons.org/licenses/by-nc-sa/4.0/>`_
license. Examples, recipes, and other code in the documentation are additionally licensed under the
`BSD 3-Clause "New" or "Revised" <https://opensource.org/license/BSD-3-Clause>`_ license.

Supporting the project
++++++++++++++++++++++
The Gammapy project is not sponsored and the development is made by the staff of `the institutes supporting the project
<https://gammapy.org/team.html#support>`_ over their research time. Any contribution is then encouraged, as punctual or
regular contributor.

Status shields
++++++++++++++

(mostly useful for developers)

* .. image:: https://app.codacy.com/project/badge/Grade/9c32a21a915d4a28823f3b44a99a2810
    :target: https://app.codacy.com/gh/gammapy/gammapy/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade
    :alt: Codacy

* .. image:: https://github.com/gammapy/gammapy/workflows/CI/badge.svg?style=flat
    :target: https://github.com/gammapy/gammapy/actions
    :alt: GitHub actions CI

* .. image:: https://codecov.io/gh/gammapy/gammapy/branch/main/graph/badge.svg?style=flat
    :target: https://codecov.io/gh/gammapy/gammapy

